@@ -1,7 +1,7 @@
 inlineCxxPlugin <-
     Rcpp:::Rcpp.plugin.maker(
 			include.before = "#include <Rclusterpp.h>", 
-      libs           = Rclusterpp:::RclusterppLdFlags(FALSE),
+      libs           = Rclusterpp::RclusterppLdFlags(FALSE),
 			package        = "Rclusterpp",
 			LinkingTo      = c("Rclusterpp", "RcppEigen", "Rcpp"),
 			Makevars       = NULL, 
